package com.yiqi.system.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.system.domain.SysDataGroupInfo;

/**
 * 组合数据详情Service接口
 *
 * @author douya
 * @date 2024-10-29
 */
public interface ISysDataGroupInfoService extends IService<SysDataGroupInfo> {

    //<editor-folder desc="基础函数">

    /**
     * 查询组合数据详情
     *
     * @param id 组合数据详情主键
     * @return 组合数据详情
     */
    public SysDataGroupInfo selectSysDataGroupInfoById(Integer id);

    /**
     * 查询组合数据详情列表
     *
     * @param sysDataGroupInfo 组合数据详情
     * @return 组合数据详情集合
     */
    public List<SysDataGroupInfo> selectSysDataGroupInfoList(SysDataGroupInfo sysDataGroupInfo);

    /**
     * 新增组合数据详情
     *
     * @param sysDataGroupInfo 组合数据详情
     * @return 结果
     */
    public int insertSysDataGroupInfo(SysDataGroupInfo sysDataGroupInfo);

    /**
     * 修改组合数据详情
     *
     * @param sysDataGroupInfo 组合数据详情
     * @return 结果
     */
    public int updateSysDataGroupInfo(SysDataGroupInfo sysDataGroupInfo);

    /**
     * 批量删除组合数据详情
     *
     * @param ids 需要删除的组合数据详情主键集合
     * @return 结果
     */
    public int deleteSysDataGroupInfoByIds(Integer[] ids);

    /**
     * 删除组合数据详情信息
     *
     * @param id 组合数据详情主键
     * @return 结果
     */
    public int deleteSysDataGroupInfoById(Integer id);


    /**
     * 修改组合数据详情状态
     *
     * @param sysDataGroupInfo 组合数据详情
     * @return 结果
     */
    public int updateSysDataGroupInfoStatus(SysDataGroupInfo sysDataGroupInfo);


    List<SysDataGroupInfo> getDataList(Integer gid, Integer status);
    //</editor-folder>
}
